import { useState } from "react";
import "./index.less";
import {
  Button,
  Collapse,
  CollapseProps,
  Form,
  Input,
  Modal,
  theme,
  Typography,
} from "antd";
import { CaretRightOutlined, PlusOutlined } from "@ant-design/icons";
import { useDomain } from "@/hook/useDomain";

const { Text } = Typography;

interface LabelProps {
  children?: JSX.Element;
}

const content = (
  <ul className="label-catalog">
    <li>切片太少</li>
    <li className="active">{"层厚>1.0mm"}</li>
  </ul>
);
const getItems = (): CollapseProps["items"] =>
  [
    {
      key: "1",
      label: "影像质量",
      children: content,
    },
    {
      key: "2",
      label: "其他",
      children: <p>1</p>,
    },
  ].map((i) => ({
    ...i,
    headerClass: "label-category-header",
    className: "label-category-item",
  }));

export const Label = (props: LabelProps) => {
  const { token } = theme.useToken();
  const [isModalOpen, setIsModalOpen] = useState(false);
  const [createLabelCategoryForm] = Form.useForm<{ name: string }>();
  const { labelDomainService } = useDomain();

  const handleOk = async () => {
    try {
      await createLabelCategoryForm.validateFields();
      const { name } = createLabelCategoryForm.getFieldsValue();
      labelDomainService.createNewLabelCategory({ name });
    } catch (error) {
      console.log(error);
    }
  };

  return (
    <div className="label-container">
      <aside>
        <Button
          block
          type="dashed"
          icon={<PlusOutlined />}
          style={{ marginBottom: 10 }}
          onClick={() => setIsModalOpen(true)}
        >
          新增标签分类
        </Button>
        <Modal
          title="新增标签分类"
          open={isModalOpen}
          onOk={handleOk}
          width={350}
          okText="确认"
          cancelText="再想想"
          onCancel={() => setIsModalOpen(false)}
        >
          <Form form={createLabelCategoryForm} style={{ marginTop: 20 }}>
            <Form.Item
              name="name"
              rules={[
                { required: true, message: "标签分类名称不能为空" },
                { max: 10, message: "不能超过十个字符" },
              ]}
            >
              <Input placeholder="请输入标签分类名称" autoComplete="off" />
            </Form.Item>
          </Form>
        </Modal>
        <Collapse
          bordered={false}
          defaultActiveKey={[]}
          expandIcon={({ isActive }) => (
            <CaretRightOutlined rotate={isActive ? 90 : 0} />
          )}
          style={{ background: token.colorBgContainer, color: token.colorText }}
          items={getItems()}
        />
      </aside>
      <main>标签相关数据</main>
    </div>
  );
};
